
# 云服务器历史漏洞修复指南

---

## 1. [Linux polkit 本地权限提升漏洞（CVE-2021-4034）修复]

该漏洞可导致本地权限提升，可通过更新 `polkit` 包修复。

**修复命令：**

```bash
yum clean all && yum makecache
yum update polkit -y
```

---

## 2. runc 文件描述符泄漏导致容器逃逸漏洞（CVE-2024-21626）修复

此漏洞可能允许容器突破隔离，修复方法为替换为最新版 `runc`。

**修复步骤：**

1. 下载新版 runc：

    ```bash
    cd /opt && wget https://github.com/opencontainers/runc/releases/download/v1.1.12/runc.amd64
    ```

2. 备份原始 runc 工具：

    ```bash
    mv /usr/bin/runc /usr/bin/runcbak
    ```

3. 更新为新版本并设置执行权限：

    ```bash
    mv /opt/runc.amd64 /usr/bin/runc
    chmod +x /usr/bin/runc
    ```

4. 重启 Docker 并检查 runc 是否更新成功：

    ```bash
    systemctl restart docker.service
    docker version
    ```

---

## 3. Spring Boot Actuator 未授权访问远程代码执行漏洞修复

未授权访问 Actuator 接口存在执行风险，需引入权限控制。

### 步骤一：在 `pom.xml` 中添加依赖

```xml
<dependency>
  <groupId>org.springframework.boot</groupId>
  <artifactId>spring-boot-starter-actuator</artifactId>
</dependency>
<dependency>
  <groupId>org.springframework.boot</groupId>
  <artifactId>spring-boot-starter-security</artifactId>
</dependency>
```

### 步骤二：在 `application.properties` 中启用认证配置

```properties
management.port=8099
management.security.enabled=true
security.user.name=yourUsername
security.user.password=yourPassword
```

> 完成后请重启服务以使配置生效。

---

## 4. Spring Boot Actuator 未授权访问漏洞修复（简化版）

仅需防止 Actuator 被任意访问时，可使用如下简化配置：

### 步骤一：在 `pom.xml` 中添加依赖

```xml
<dependency>
  <groupId>org.springframework.boot</groupId>
  <artifactId>spring-boot-starter-security</artifactId>
</dependency>
```

### 步骤二：配置账号密码启用访问控制

```properties
management.security.enabled=true
security.user.name=admin
security.user.password=admin
```


